/*****
   CHK_DRV()

   A FoxPro API function to check for
   the existence of a hard disk partition
   or a floppy disk in floppy drives.

   Expects 1 parameter:
      1st parameter must be a drive with colon

   A logical .T. is returned to FoxPro
   if the drive exists and, for floppy drives,
   if a formatted floppy is in the drive and
   the drive is latched.  Otherwise a logical
   .F. is returned without the DOS error message.
   Message about incorrect parameter is displayed
   in WAIT window using _Execute.
*****/

#include <stdio.h>
#include <stdlib.h>
#include <dos.h>
#include <fcntl.h>
#include <string.h>
#include <io.h>
#include <ctype.h>
#include <errno.h>
#include <pro_ext.h>

int FAR chk_(ParamBlk FAR *parm)
{
    Value *v;
    char *p;
    union REGS inregs, outregs;

    v = &parm->p[0].val;
    p = _HandToPtr(v->ev_handle);
    if (v->ev_length != 2 || !isalpha(*p) || p[1] != ':') {
       _Execute("WAIT WINDOW 'Parameter passed to chk_drv must be a letter with colon'");
       _RetLogical(0);
    } else {
        inregs.x.ax = 0x0401;   // int 13h function 4, verify disk sectors
        inregs.x.cx = 0x0001;   // track 0, sector 1
        inregs.x.dx = toupper(*p) - 'A';    // drive A=0, B=1, ...
        int86(0x13, &inregs, &outregs);     // check drive
        int86(0x13, &inregs, &outregs);     // make a list & check it twice
        _RetLogical(outregs.h.ah == 0);     // return result
    }
    return 0;
}

FoxInfo myFoxInfo[] = {
  { "CHK_DRV",
     chk_,
     1,
     "C"}
};

FoxTable _FoxTable = {
    (FoxTable FAR *) 0,
    sizeof( myFoxInfo) / sizeof( FoxInfo ),
    myFoxInfo
};

